@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014  Stéphane Bard <stephane.bard@gmail.com>
+# Copyright (C) 2019  Stéphane Bard <stephane.bard@gmail.com>
 #
 # This file is part of hg_delivery
 #
@@ -12,8 +12,6 @@ import os
 import sys
 import transaction
 
-from sqlalchemy import engine_from_config
-
 from pyramid.paster import (
     get_appsettings,
     setup_logging,
@@ -21,11 +19,13 @@ from pyramid.paster import (
 
 from pyramid.scripts.common import parse_vars
 
+from ..models.meta import Base
 from ..models import (
-    DBSession,
-    Project,
-    Base,
+    get_engine,
+    get_session_factory,
+    get_tm_session,
     )
+from ..models import Project, RemoteLog, Group, User, Acl, Task, ProjectGroup, Macro, MacroRelations  # noqa
 
 
 def usage(argv):
@@ -42,12 +42,13 @@ def main(argv=sys.argv):
     options = parse_vars(argv[2:])
     setup_logging(config_uri)
     settings = get_appsettings(config_uri, options=options)
-    engine = engine_from_config(settings, 'sqlalchemy.')
-    DBSession.configure(bind=engine)
 
-    # Base.metadata.drop_all(engine)
+    engine = get_engine(settings)
     Base.metadata.create_all(engine)
 
-    # with transaction.manager:
-    #   add here your projects objects ...
-    #   DBSession.add(project)
+    session_factory = get_session_factory(engine)
+
+    with transaction.manager:
+        dbsession = get_tm_session(session_factory, transaction.manager)
+        # add there your init objects
+        # dbsession.add(model)
