@@ -193,7 +193,7 @@ function push_to(target_project_id, target_url, force_branch){
              fetch_this_other_project(link);}, 10);
         } else if(json_response.new_branch_stop){
           // dialog : should we force ?
-          $('#confirm_force_push_dialog .modal-body').html("Should we push them ?<br><br>"+json_response.lst_new_branches.join(','));
+          $('#confirm_force_push_dialog .modal-body').html("Should we push them ?<br><br>"+json_response.lst_new_branches.join('<br>'));
           $('#abort_new_branch').off().on('click',function(){$('#container_alert').delay(1000).html('');});
           $('#new_branch').off().on('click',function(){ $('#confirm_force_push_dialog').modal('hide');$('#container_alert').html(''); push_to(target_project_id, target_url, true);});
           $('#confirm_force_push_dialog').modal('show');
@@ -326,9 +326,25 @@ function change_project_to_this_release(active_a, target_url, target_refresh_url
              $('#target_revision').text($(active_a).text());
              $('#confirm_move_dialog').modal('show');
 
+             // better to check if task id exist rather than input, because user may not have save it
+             if($('#tasks_list button.btn.delete[data-id]').size()>0){
+               $('label.additional_task_selector').show();
+               $('label.no_task_found').hide();
+             } else {
+               $('label.additional_task_selector').hide();
+               $('label.no_task_found').show();
+             }
+
+             // force flag
+             $('input[name="run_task_flag"]').prop('checked', true);
+
              $('#move_to').off().on('click',function(){
-               var lst_brother = $('#possible_update a.active').map(function(_i,_item){return $(_item).data('id');}).toArray();
+               var lst_brother   = $('#possible_update a.active').map(function(_i,_item){return $(_item).data('id');}).toArray();
+               var run_task_flag = $('input[name="run_task_flag"]').prop('checked') === true ? true : false;
+
                $.ajax({url:target_url+lst_brother.join('/'),
+                       data:{'run_task_flag':run_task_flag},
+                       method:'POST',
                        beforeSend:function(){
                          $('#confirm_move_dialog').modal('hide');
                          $(active_a).hide();
@@ -426,6 +442,10 @@ function fetch_this_other_project(active_a){
                 $('#p_name_remote').text(remote_project_name);
                 $('#p_name_local').text(local_project_name);
                 $('#button_push').removeAttr('disabled');
+              } else if (!json_response.result && json_response.message){
+                _alert_html = '<div class="alert alert-danger"><button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>';
+                _alert_html += '<strong>'+json_response.message+'</strong></div>';
+                $('#container_alert').html(_alert_html);
               }
               finish_push_pull_evaluation();
             },
@@ -445,6 +465,10 @@ function fetch_this_other_project(active_a){
                 $('#p_name_remote').text(remote_project_name);
                 $('#p_name_local').text(local_project_name);
                 $('#button_pull').removeAttr('disabled');
+              } else if (!json_response.result && json_response.message){
+                _alert_html = '<div class="alert alert-danger"><button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>';
+                _alert_html += '<strong>'+json_response.message+'</strong></div>';
+                $('#container_alert').html(_alert_html);
               }
               finish_push_pull_evaluation();
             },
@@ -733,6 +757,7 @@ function update_user(target_url){
         $('.alert-success').delay(3000).fadeOut(500,function(){$(this).remove();});
       }
       update_user_list();
+      document.location.reload(true);
     } else if(json_response.explanation){
       _alert_html = '<div class="alert alert-danger"><button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>';
       _alert_html += '<strong>'+json_response.explanation+'</strong></div>';
@@ -791,6 +816,8 @@ function delete_user(button,target_delete_url){
 }
 
 function update_user_list(){
+  $('div.missing').remove();
+  $('#overview').show();
   var target_url = $('#users_overview').data('update_url');
   $.ajax({ url:target_url,
     method:'GET',
@@ -805,6 +832,7 @@ function update_user_list(){
           var button_update = "<td><button class = \"btn btn-default\" onclick = \"edit_user('" + user.update_url + "','"+ user.get_url +"',"+user.id+")\">edit user properties</button></td>";
           var button_delete = "<td><button class = \"btn btn-default\" onclick = \"delete_user(this,'" + user.delete_url + "')\">delete</button></td>";
           $('#users_overview').append('<tr>'+name+email+creation_date+button_acl+button_update+button_delete+'</tr>');
+          document.location.reload(true);
         });
       } else {
         $('#users_overview').append('<tr><td colspan="5" style="text-align:center;padding-top:20px">No Users defined</td></tr>');
@@ -832,7 +860,7 @@ function add_project(target_url, refresh_projects_list_url){
       $.ajax({url: refresh_projects_list_url,
               method:'GET',
               success:function(html_response){
-                $('#projects_list').parent().html(html_response);
+                $('#projects_list').parent().html(html_response).show();
               }});
 
       if(json_response.explanation){
@@ -1194,7 +1222,7 @@ function run_this_macro(button, macro_name, macro_run_url, force_branch){
               $('.alert-success').delay(3000).fadeOut(500,function(){$(this).remove();});
             } else if(json_response.new_branch_stop){
               // dialog : should we force ?
-              $('#confirm_force_push_dialog .modal-body').html("Should we push them ?<br><br>"+json_response.lst_new_branches.join(','));
+              $('#confirm_force_push_dialog .modal-body').html("Should we push them ?<br><br>"+json_response.lst_new_branches.join('<br>'));
               $('#abort_new_branch').off().on('click',function(){$('#container_alert').delay(1000).html('');});
               $('#new_branch').off().on('click',function(){ $('#confirm_force_push_dialog').modal('hide');$('#container_alert').html(''); run_this_macro(button, macro_name, macro_run_url, true);});
               $('#confirm_force_push_dialog').modal('show');
@@ -1221,8 +1249,8 @@ function run_this_macro(button, macro_name, macro_run_url, force_branch){
  * based on button disable or not check
  */
 function run_project_tasks(){
-  if(!$('button.run_task').is(':disabled')){
-    $('button.run_task').click();
+  if(!$('form[name="project_tasks"] button.run_task').is(':disabled')){
+    $('form[name="project_tasks"] button.run_task').click();
   }
 }
 
